@@ -362,14 +362,14 @@ def get_group_trends(request, project=None):
     limit = min(100, int(request.REQUEST.get('limit', 10)))
 
     if project:
-        project_list = [project]
+        project_dict = {project.pk: project}
     else:
-        project_list = get_project_list(request.user).values()
+        project_dict = get_project_list(request.user)
 
     base_qs = Group.objects.filter(
-        project__in=project_list,
+        project__in=project_dict.keys(),
         status=0,
-    ).select_related('project').order_by('-score')
+    ).order_by('-score')
 
     if has_trending():
         group_list = list(Group.objects.get_accelerated(base_qs, minutes=(
@@ -383,6 +383,9 @@ def get_group_trends(request, project=None):
             last_seen__gte=cutoff_dt
         )[:limit])
 
+    for group in group_list:
+        group._project_cache = project_dict.get(group.project_id)
+
     data = transform_groups(request, group_list, template='sentry/partial/_group_small.html')
 
     response = HttpResponse(json.dumps(data))
